@@ -6,19 +6,28 @@ from .Primitives2D import Primitives2D
 
 
 class ModelerRMxprt(Modeler):
-    """ """
+    """Provides the Modeler RMxprt application interface."""
 
     def __init__(self, parent):
         Modeler.__init__(self, parent)
 
     @property
     def oeditor(self):
-        """ """
+        """Editor."""
         return self.odesign.SetActiveEditor("Machine")
 
 
 class Modeler2D(GeometryModeler):
-    """ """
+    """Provides the Modeler 2D application interface.
+    
+    Parameters
+    ----------
+    application :
+    
+    is3d : bool, optional
+        Whether the model is 3D. The default is ``False``.
+    
+    """
 
     def __init__(self, application):
         GeometryModeler.__init__(self, application, is3d=False)
@@ -31,28 +40,36 @@ class Modeler2D(GeometryModeler):
 
     @property
     def primitives(self):
-        """ """
+        """Primitives.
+        
+        Returns
+        -------
+        :class:`pyaedt.modeler.Primitives2D.Primitives2D` 
+        
+        """
         if self._primitivesDes != self._parent.project_name + self._parent.design_name:
-            self._primitives = Primitives2D(self._parent, self)
+            self._primitives.refresh()
             self._primitivesDes = self._parent.project_name + self._parent.design_name
         return self._primitives
 
     @aedt_exception_handler
     def calculate_radius_2D(self, object_name, inner=False):
-        """Calculate the extremity of an object in radial direction. If inner is True, then return
-            the maximum, else return the minimum)
+        """Calculate the extremity of an object in the radial direction. 
 
         Parameters
         ----------
-        object_name :
-            object from which calculate radius
-        inner :
-             (Default value = False)
+        object_name : str
+            name of the object from which to calculate the radius.
+        inner : bool, optional
+             The default is ``False``.
 
         Returns
         -------
-        type
-            radius
+        float
+            Radius value.
+            .. note::
+                If ``inner=True``, then the maximum is returned; otherwise,
+                the minimum is returned.
 
         """
         oVertexIDs = self.oeditor.GetVertexIDsFromObject(object_name)
@@ -76,17 +93,19 @@ class Modeler2D(GeometryModeler):
 
     @aedt_exception_handler
     def radial_split_2D(self, radius, name):
-        """Split Stator and rotor for Mesh Refinement
+        """Split the stator and rotor for mesh refinement.
 
         Parameters
         ----------
-        radius :
+        radius : float
+            Radius of the circle.   
+        name : str
+            Name of the circle. 
             
-        name :
-            
-
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         self.oeditor.CreateCircle(
@@ -130,4 +149,4 @@ class Modeler2D(GeometryModeler):
             ])
 
         self.subtract(name, name + "1")
-        return True
\ No newline at end of file
+        return True
