@@ -4,7 +4,16 @@ from .Modeler import GeometryModeler
 from  .Primitives3D import Primitives3D
 
 class Modeler3D(GeometryModeler):
-    """AEDT 3D Modeler"""
+    """Provides the Modeler 3D application interface.
+    
+    Parameters
+    ----------
+    application :
+    
+    is3D : bool, optional
+        Whether the model is 3D. The default is ``True``.
+    
+    """
     def __init__(self, application):
         GeometryModeler.__init__(self, application, is3d=True)
         self._primitives = Primitives3D(self._parent, self)
@@ -16,31 +25,37 @@ class Modeler3D(GeometryModeler):
 
     @property
     def primitives(self):
-        """ """
+        """Primitives.
+        
+        Returns
+        -------
+        :class:`pyaedt.modeler.Primitives3D.Primitives3D`
+        
+        """
         if self._primitivesDes != self._parent.project_name + self._parent.design_name:
-            self._primitives = Primitives3D(self._parent, self)
+            self._primitives.refresh()
             self._primitivesDes = self._parent.project_name + self._parent.design_name
         return self._primitives
 
     @aedt_exception_handler
     def create_3dcomponent(self, component_file, component_name=None, variables_to_include=[], exclude_region=False):
-        """Create 3D Component file
+        """Create a 3D component file.
 
         Parameters
         ----------
-        component_file :
-            full path to the a3dcomp file
-        component_name :
-            Component name (Default value = None)
-        variables_to_include :
-             (Default value = [])
-        exclude_region :
-             (Default value = False)
+        component_file : str
+            Full path to the A3DCOMP file.
+        component_name : str, optional
+            Name of the component. The default is ``None``.
+        variables_to_include : list, optional
+             List of variables to include. The default is ``[]``.
+        exclude_region : bool, optional
+             Whether to exclude the region. The default is ``False``.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if self._parent.design_type == "Icepak":
@@ -55,7 +70,7 @@ class Modeler3D(GeometryModeler):
                "SecurityMessage:=", "", "Password:=", "", "EditPassword:=", "",
                "PasswordType:=", "UnknownPassword", "HideContents:=", True,
                "ReplaceNames:=", True, "ComponentOutline:=", "None"]
-        objs = self.primitives.get_all_objects_names()
+        objs = self.primitives.object_names
         for el in objs:
             if "Region" in el and exclude_region:
                 objs.remove(el)
@@ -98,4 +113,4 @@ class Modeler3D(GeometryModeler):
         arg2.append("MeshOperations:="), arg2.append(meshops)
         arg3 = ["NAME:ImageFile", "ImageFile:=", ""]
         self.oeditor.Create3DComponent(arg, arg2, component_file, arg3)
-        return True
\ No newline at end of file
+        return True
