@@ -1,25 +1,44 @@
 import sys
 from collections import defaultdict
 
-from ..generic.general_methods import aedt_exception_handler
+from ..generic.general_methods import aedt_exception_handler, retry_ntimes
 from .Object3d import Padstack, Components3DLayout, Geometries3DLayout, Pins3DLayout, Nets3DLayout, \
     _uname
 from .Primitives import _ironpython, default_materials
 from .GeometryOperators import GeometryOperators
 import pkgutil
 modules = [tup[1] for tup in pkgutil.iter_modules()]
-if 'clr' in modules:
+if 'clr' in modules or _ironpython:
     import clr
     from System import String
+    import System
 
 
 class Primitives3DLayout(object):
-    """Class for management of all Primitives of HFSS3DLayout"""
+    """Manages primitives in HFSS 3D Layout.
+    
+    Parameters
+    ----------
+    parent : str
+        Name of the parent AEDT application.
+    modeler : str
+        Name of the modeler.
+    
+    """
     @aedt_exception_handler
     def __getitem__(self, partname):
-        """
-        :param partname: if integer try to get the object id. if string, trying to get object Name
-        :return: part object details
+        """Retrieve a part.
+        
+        Parameters
+        ----------
+        partname: int or str
+           Part ID or part name. 
+        
+        Returns
+        -------
+        type
+          Part object details.
+          
         """
         for el in self.geometries:
             if el == partname:
@@ -41,7 +60,14 @@ class Primitives3DLayout(object):
 
     @property
     def components(self):
-        """:return: Component List from EDB. If no EDB is present none is returned"""
+        """Components.
+        
+        Returns
+        -------
+        list
+            List of components from EDB. If EDB is not present, ``None`` is returned.
+        
+        """
         try:
             comps = list(self.modeler.edb.core_components.components.keys())
         except:
@@ -52,9 +78,16 @@ class Primitives3DLayout(object):
 
     @property
     def geometries(self):
-        """:return: Geometries List from EDB. If no EDB is present none is returned"""
+        """Geometries.
+        
+        Returns
+        -------
+        list
+            List of geometries from EDB. If EDB is not present, ``None`` is returned.
+           
+           """
         try:
-            prims = self.modeler.edb.active_layout.Primitives
+            prims = self.modeler.edb.core_primitives.primitives
         except:
             prims = []
         for el in prims:
@@ -63,8 +96,8 @@ class Primitives3DLayout(object):
                 name = clr.Reference[System.String]()
                 response = el.GetProductProperty(0, 1, name)
             else:
-                name = String("")
-                response, name = el.GetProductProperty(0, 1, name)
+                val = String("")
+                response, name = el.GetProductProperty(0, 1, val)
             elval = el.GetType()
             elid = el.GetId()
             if not name:
@@ -85,21 +118,39 @@ class Primitives3DLayout(object):
 
     @property
     def pins(self):
-        """:return: Pins List from EDB. If no EDB is present none is returned"""
+        """Pins.
+        
+        Returns
+        -------
+        list
+            List of pins from EDB. If EDB is not present, ``None`` is returned.
+        
+        """
         try:
             pins_objs = list(self.modeler.edb.pins)
         except:
             pins_objs = []
         for el in pins_objs:
-            val = String("")
-            response, name = el.GetProductProperty(0, 11, val)
-            #name = el.GetComponent().GetName() + "-" + el.GetName()
+            if _ironpython:
+                name = clr.Reference[System.String]()
+                response = el.GetProductProperty(0, 11, name)
+            else:
+                val = String("")
+                response, name = el.GetProductProperty(0, 11, val)
+            name = str(name).strip("'")
             self._pins[name] = Pins3DLayout(self, el.GetComponent().GetName(), el.GetName(), name)
         return self._pins
 
     @property
     def nets(self):
-        """:return: Nets List from EDB. If no EDB is present none is returned"""
+        """Nets.
+        
+        Returns
+        -------
+        list
+            List of nets from EDB. If EDB is not present, ``None`` is returned.
+        
+        """
         try:
             nets_objs = list(self.modeler.edb.core_nets.nets)
         except:
@@ -110,57 +161,71 @@ class Primitives3DLayout(object):
 
     @property
     def defaultmaterial(self):
-        """ """
+        """Default materials.
+        
+        Returns
+        -------
+        list
+            List of default materials.
+          
+        """
         return default_materials[self._parent._design_type]
 
     @property
-    def messenger(self):
-        """ """
+    def _messenger(self):
+        """Messenger."""
         return self._parent._messenger
 
     @property
     def version(self):
-        """ """
+        """AEDT version.
+        
+        Returns
+        -------
+        str
+            Version of AEDT.
+        
+        """
         return self._parent._aedt_version
 
     @property
     def modeler(self):
-        """ """
+        """Modeler."""
         return self._modeler
 
     @property
     def oeditor(self):
-        """ """
+        """Editor."""
         return self.modeler.oeditor
 
     @property
     def opadstackmanager(self):
-        """ """
-        return self._parent._oproject.GetDefinitionManager().GetManager("Padstack")
+        """Padstack manager. """
+        return retry_ntimes(10, self._parent._oproject.GetDefinitionManager().GetManager, "Padstack")
 
     @property
     def model_units(self):
-        """ """
+        """Model units."""
         return self.modeler.model_units
 
     @property
     def Padstack(self):
-        """ """
+        """Padstack."""
         return Padstack()
 
     @aedt_exception_handler
     def new_padstack(self, name="Padstack"):
-        """Return a new Padstack object that can be used in HFSS 3D Layout to create a new Padstack
+        """Create a `Padstack` object that can be used to create a padstack.
 
         Parameters
         ----------
-        name :
-            Padstack Name (Default value = "Padstack")
+        name : str, optional
+            Name of the padstack. The default is ``"Padstack"``.
 
         Returns
         -------
         type
-            Padstack Object if name is doesn't already exists
+            Padstack object if a padstack with this name does not already exist.
 
         """
         if name in self.padstacks:
@@ -171,15 +236,12 @@ class Primitives3DLayout(object):
 
     @aedt_exception_handler
     def init_padstacks(self):
-        """Read all Padstack from HFSS 3D Layout
+        """Read all padstacks from HFSS 3D Layout.
         
-        :return: True
-
-        Parameters
-        ----------
-
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         names = GeometryOperators.List2list(self.opadstackmanager.GetNames())
@@ -246,19 +308,20 @@ class Primitives3DLayout(object):
 
     @aedt_exception_handler
     def change_net_visibility(self, netlist=None, visible=False):
-        """Change the visibility of a net or net list
+        """Change the visibility of one or more nets.
 
         Parameters
         ----------
-        netlist :
-            single net or netlist to visualize (Default value = None)
-        visible :
-            Boolean (Default value = False)
+        netlist : str  or list, optional
+            One or more nets to visualize. The default is ``None``.
+        visible : bool, optional
+            Whether to make the selected nets visible. The 
+            The default value is ``False``.
 
         Returns
         -------
-        type
-            Boolean
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if not netlist:
@@ -278,33 +341,36 @@ class Primitives3DLayout(object):
     @aedt_exception_handler
     def create_via(self, padstack="PlanarEMVia", x=0, y=0, rotation=0, hole_diam=None, top_layer=None, bot_layer=None,
                    name=None, netname=None):
-        """Create a Via based on existing padstack
+        """Create a via based on an existing padstack.
 
         Parameters
         ----------
-        padstack :
-            String containing the Padstack Name (Default value = "PlanarEMVia")
-        x :
-            x position (Default value = 0)
-        y :
-            y position (Default value = 0)
-        rotation :
-            angle rotation in deg (Default value = 0)
+        padstack : str, optional
+            Name of the padstack. The default is ``"PlanarEMVia"``.
+        x : float, optional
+            Position on the X axis. The default is ``0``.
+        y : float, optional
+            Position on the Y axis. The default is ``0``.
+        rotation : float, optional
+            Angle rotation in degrees. The default is ``0``.
         hole_diam :
-            hole diameter. If None Override is disabled (Default value = None)
-        top_layer :
-            top layer (Default value = None)
-        bot_layer :
-            bottom layer (Default value = None)
-        name :
-            Via Name (Default value = None)
-        netname :
-            optional Netname (Default value = None)
+            Diameter of the hole. The default is ``None``, in which case
+            the override is disabled.
+        top_layer : str, optional
+            Top layer. The default is ``None``.
+        bot_layer : str, optional
+            Bottom layer. The default is ``None``.
+        name : str, optional
+            Name of the via. The default is ``None``, in which case the 
+            default name is assigned.
+        netname : str, optional
+            Name of the net. The default is ``None``, in which case the 
+            default name is assigned.
 
         Returns
         -------
-        type
-            Name of the created object, if successful
+        str
+            Name of the via created when successful.
 
         """
         layers = self.modeler.layers.all_signal_layers
@@ -344,27 +410,29 @@ class Primitives3DLayout(object):
 
     @aedt_exception_handler
     def create_circle(self, layername, x, y, radius, name=None, netname=None):
-        """Create Circle on specific layer
+        """Create a circle on a layer.
 
         Parameters
         ----------
-        layername :
-            layername
-        x :
-            x position float
-        y :
-            y position float
-        radius :
-            radius float
-        name :
-            Object Name (Default value = None)
-        netname :
-            optional Netname (Default value = None)
+        layername : str
+            Name of the layer.
+        x : float
+            Position on the X axis.
+        y : float
+            Position on the Y axis.
+        radius : float
+            Radius of the circle.
+        name : str, optional
+            Name of the circle. The default is ``None``, in which case the 
+            default name is assigned.
+        netname : str, optional
+            Name of the net. The default is ``None``, in which case the 
+            default name is assigned.
 
         Returns
         -------
-        type
-            Name of the created object, if successful
+        str
+            Name of the circle created when successful.
 
         """
         if not name:
@@ -391,42 +459,34 @@ class Primitives3DLayout(object):
         return name
 
     @aedt_exception_handler
-    def create_rectangle(self, layername, ax, ay, bx, by, cr=0, ang=0, name=None, netname=None):
-        """Create a Rectangle on specific layer
+    def create_rectangle(self, layername, origin, dimensions, corner_radius=0, angle=0, name=None, netname=None):
+        """Create a rectangle on a layer.
 
         Parameters
         ----------
-        layername :
-            layername
-        x :
-            x position float
-        y :
-            y position float
-        radius :
-            radius float
-        name :
-            Object Name (Default value = None)
-        netname :
-            optional Netname (Default value = None)
-        ax :
-            
-        ay :
-            
-        bx :
-            
-        by :
-            
-        cr :
-             (Default value = 0)
-        ang :
-             (Default value = 0)
+        layername : str
+            Name of the layer.
+        origin : list
+            Origin of the coordinate system in a list of ``[x, y, z]`` coordinates.
+        dimensions : list
+            Dimensions for the box in a list of ``[x, y, z]`` coordinates.
+        corner_radius : float, optional
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        name : str, optional
+            Name of the rectangle. The default is ``None``, in which case the 
+            default name is assigned.
+        netname : str, optional
+            Name of the net. The default is ``None``, in which case the 
+            default name is assigned.
 
         Returns
         -------
-        type
-            Name of the created object, if successful
+        str
+            Name of the rectangle created when successful.
 
         """
+
         if not name:
             name = _uname()
         else:
@@ -439,12 +499,12 @@ class Primitives3DLayout(object):
         vArg2.append("Name:="), vArg2.append(name)
         vArg2.append("LayerName:="), vArg2.append(layername)
         vArg2.append("lw:="), vArg2.append("0")
-        vArg2.append("Ax:="), vArg2.append(self.arg_with_dim(ax))
-        vArg2.append("Ay:="), vArg2.append(self.arg_with_dim(ay))
-        vArg2.append("Bx:="), vArg2.append(self.arg_with_dim(bx))
-        vArg2.append("By:="), vArg2.append(self.arg_with_dim(by))
-        vArg2.append("cr:="), vArg2.append(self.arg_with_dim(cr))
-        vArg2.append("ang="), vArg2.append(self.arg_with_dim(ang))
+        vArg2.append("Ax:="), vArg2.append(self.arg_with_dim(origin[0]))
+        vArg2.append("Ay:="), vArg2.append(self.arg_with_dim(origin[1]))
+        vArg2.append("Bx:="), vArg2.append(self.arg_with_dim(dimensions[0]))
+        vArg2.append("By:="), vArg2.append(self.arg_with_dim(dimensions[1]))
+        vArg2.append("cr:="), vArg2.append(self.arg_with_dim(corner_radius))
+        vArg2.append("ang="), vArg2.append(self.arg_with_dim(angle))
         vArg1.append(vArg2)
         self.oeditor.CreateRectangle(vArg1)
         if self.isoutsideDesktop:
@@ -454,32 +514,39 @@ class Primitives3DLayout(object):
         return name
 
     @aedt_exception_handler
-    def create_line(self, layername, lw=1, x=[], y=[], start_style=0, end_style=0, name=None, netname=None):
-        """Create Line based on specific list of point
+    def create_line(self, layername, center_line_list, lw=1, start_style=0, end_style=0, name=None, netname=None):
+        """Create a line based on a list of points.
 
         Parameters
         ----------
-        layername :
-            layer name on which create the object
-        lw :
-            line width (Default value = 1)
-        x :
-            array of float containing x point of each point of the line (Default value = [])
-        y :
-            array of float containing y point of each point of the line (Default value = [])
+        layername : str
+            Name of the layer to create the line on.
+        center_line_list : list
+            List of centerline coordinates in the form of ``[x, y, z]``.
+        lw : float, optional
+            Line width. The default is ``1``.
         start_style :
-            start style of the line. 0 Flat, 1 Extended, 2 Round (Default value = 0)
+            Starting style of the line. Options are:
+            
+            * ``0`` - Flat
+            * ``1`` - Extended
+            * ``2`` - Round
+            
+            The default is ``0``.
         end_style :
-            end style of the line. 0 Same as start, 1 Flat, 2 Extended, 3 Round (Default value = 0)
-        name :
-            Object Name (Default value = None)
-        netname :
-            optional Netname (Default value = None)
+            Ending style of the line. The options are the same as
+            those for ``start_style``. The default is ``0``.
+        name : str, optional
+            Name  of the line. The default is ``None``, in which case the 
+            default name is assigned.
+        netname : str, optional
+            Name of the net. The default is ``None``, in which case the 
+            default name is assigned.
 
         Returns
         -------
-        type
-            Name of the created object, if successful
+        str
+            Name of the line created when successful.
 
         """
         if not name:
@@ -490,12 +557,12 @@ class Primitives3DLayout(object):
                 name = _uname(name)
         arg = ["NAME:Contents", "lineGeometry:="]
         arg2 = ["Name:=", name, "LayerName:=", layername, "lw:=", self.arg_with_dim(lw), "endstyle:=", end_style,
-                "StartCap:=", start_style, "n:=", len(x), "U:=", self.model_units]
-        for a, b in zip(x, y):
+                "StartCap:=", start_style, "n:=", len(center_line_list), "U:=", self.model_units]
+        for a in center_line_list:
             arg2.append("x:=")
-            arg2.append(a)
+            arg2.append(a[0])
             arg2.append("y:=")
-            arg2.append(b)
+            arg2.append(a[1])
         arg.append(arg2)
         self.oeditor.CreateLine(arg)
         if self.isoutsideDesktop:
@@ -507,18 +574,19 @@ class Primitives3DLayout(object):
 
     @aedt_exception_handler
     def arg_with_dim(self, Value, sUnits=None):
-        """
+        """Retrieve arguments with dimensions.
 
         Parameters
         ----------
         Value :
             
         sUnits :
-             (Default value = None)
+             The default is ``None``.
 
         Returns
         -------
-
+        str
+            String containing the value or value and the units if `sUnits` is not ``None``.
         """
         if type(Value) is str:
             val = Value
@@ -527,4 +595,4 @@ class Primitives3DLayout(object):
                 sUnits = self.model_units
             val = "{0}{1}".format(Value, sUnits)
 
-        return val
\ No newline at end of file
+        return val
