@@ -1,15 +1,8 @@
 """
-Setup Library Class
-----------------
+This module contains these classes: `Setup`, `Setup3DLayout`, and `SetupCircuit`.
 
-
-**Description**
-
-
-This class contains all the functionalities to create and edit a setup. It is based on templates in order to allow to create and modify setup properties easily
-
-
-================
+This module provides all functionalities for creating and editing setups in AEDT.
+It is based on templates to allow for easy creation and modification of setup properties.
 
 """
 from __future__ import absolute_import
@@ -19,57 +12,58 @@ import os.path
 
 from ..generic.general_methods import aedt_exception_handler, generate_unique_name
 
-from .SetupTemplates import SweepHFSS, SweepQ3D, SetupKeys
+from .SetupTemplates import SweepHFSS, SweepQ3D, SetupKeys, SweepHFSS3DLayout
 from ..application.DataHandlers import tuple2dict, dict2arg
 
 
 class Setup(object):
-    """This Class defines the functions to initialize, create and update a Setup in Electronic Desktop"""
+    """Initializes, creates, and updates a 3D setup.
+    
+    Parameters
+    ----------
+    parent: str
+        Inherited parent object.
+    solutiontype: 
+        Type of the setup.
+    setupname: str, optional
+        Name of the setup. The default is ``"MySetupAuto"``.
+    isnewsetup: bool, optional
+        Whether to create the setup from a template. The default is ``True``.
+        If ``False``, access is to the existing setup.
+     
+    """
 
     @property
     def parent(self):
-        """ """
+        """Parent."""
         return self._parent
 
     @parent.setter
     def parent(self, value):
-        """
-
-        Parameters
-        ----------
-        value :
-            
-
-        Returns
-        -------
-
-        """
         self._parent = value
-        pass
 
     @property
     def omodule(self):
-        """ """
+        """Analysis module."""
         return self._parent.oanalysis
 
     def __repr__(self):
         return "SetupName " + self.name + " with " + str(len(self.sweeps)) + " Sweeps"
 
     def __init__(self, parent, solutiontype, setupname="MySetupAuto", isnewsetup=True):
-        """
-        :param parent: AEDT Module for Analysis Setup
-        :param setupname: Setup Name
-        :param solutiontype: Setup Type of Application.SolutionType
-        :param isnewsetup: Boolean. True if is a new setup to be created from template. False to access existing Setup
-        """
+        
         self._parent = None
         self.parent = parent
-        self.setuptype = solutiontype
+        if isinstance(solutiontype, int):
+            self.setuptype = solutiontype
+        else:
+            self.setuptype = SetupKeys.defaultSetups[solutiontype]
+
         self.name = setupname
         self.props = {}
         self.sweeps = []
         if isnewsetup:
-            setup_template = SetupKeys.SetupTemplates[solutiontype]
+            setup_template = SetupKeys.SetupTemplates[self.setuptype]
             for t in setup_template:
                 tuple2dict(t, self.props)
         else:
@@ -97,48 +91,14 @@ class Setup(object):
             except:
                 self.props = OrderedDict()
 
-
-    @aedt_exception_handler
-    def check_dict(self, listin, name, out):
-        """
-
-        Parameters
-        ----------
-        listin :
-            
-        name :
-            
-        out :
-            
-
-        Returns
-        -------
-
-        """
-        arg = ["Name:" + name.replace("__", " ")]
-        for a in listin:
-            if type(a) is tuple:
-                if type(a[1]) is list and type(a[1][0]) is tuple:
-                    arg = self.check_dict(a[1], a[0], arg)
-                else:
-                    arg.append(a[0].replace("__", " ") + ":=")
-                    arg.append(a[1])
-            else:
-                arg.append(a)
-        out.append(arg)
-        return out
-
     @aedt_exception_handler
     def create(self):
-        """Insert a new Setup based on Class settings into the AEDT Application
-        
-        :return: the argument list
-
-        Parameters
-        ----------
-
+        """Add a new setup based on class settings in AEDT.
+              
         Returns
         -------
+        dict
+            Dictionary of arguments.
 
         """
         soltype = SetupKeys.SetupNames[self.setuptype]
@@ -149,17 +109,17 @@ class Setup(object):
 
     @aedt_exception_handler
     def update(self, update_dictionary=None):
-        """update the setup based on the class argument or to the updated dictionary passed as arcument
+        """Update the setup based on either the class argument or a dictionary.
 
         Parameters
         ----------
-        update_dictionary :
-            optional dictionary of settings to apply (Default value = None)
+        update_dictionary : optional
+            Dictionary to use to update the setup. The default is ``None``.
 
         Returns
         -------
-        type
-            bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if update_dictionary:
@@ -172,27 +132,29 @@ class Setup(object):
         return True
 
     @aedt_exception_handler
-    def _expression_cache(self, expression_list, report_type_list,intrinsics_list, isconvergence_list,
+    def _expression_cache(self, expression_list, report_type_list, intrinsics_list, isconvergence_list,
                           isrelativeconvergence, conv_criteria):
-        """
+        """Retrieve data from the expression setup cache.
 
         Parameters
         ----------
-        expression_list :
+        expressions_list : list
+            List of formulas to retrieve. 
+        report_type_list : list
+            List of report types for the expressions. 
+        intrinsics_list : list
+            List of intrinsic expressions for the expressions. 
+        isconvergence_list : list
+            List of Boolean values indicating whether the expressions are in 
+            the convergence criteria.
+        isrelativeconvergence : bool
             
-        report_type_list :
-            
-        intrinsics_list :
-            
-        isconvergence_list :
-            
-        isrelativeconvergence :
-            
-        conv_criteria :
-            
-
+        conv_criteria:
+        
         Returns
         -------
+        list
+            List of the data.
 
         """
         if isrelativeconvergence:
@@ -261,27 +223,31 @@ class Setup(object):
     @aedt_exception_handler
     def enable_expression_cache(self, expressions, report_type="Fields", intrinsics='', isconvergence=True,
                                 isrelativeconvergence=True, conv_criteria=1):
-        """Enable Setup Expression Cache
+        """Enable an expression cache.
 
         Parameters
         ----------
+        expressions : str or list
+            One or more formulas to add to the expression cache. 
+        report_type : str or list, optional
+            Type of the report for the expression. The default is ``Fields``. If a list of expressions
+            is supplied, supply a corresponding list of report types.
+        intrinsics : str or list, optional
+            Intrinsic functions for the expressions. The default is ``""``. If a list of expressions
+            is supplied, a corresponding list of intrinsic functions must be supplied.
+        isconvergence : bool or str or list, optional
+            Whether the expression is in the convergence criteria. The default is ``True``.
+            If a list of expressions is supplied, a corresponding list of Boolean values must be
+            supplied.
+        isrelativeconvergence : bool, optional
+            The default is ``True``.
         conv_criteria :
-            param isrelativeconvergence: (Default value = 1)
-        expressions :
-            Formula to be added to the expression cache. It can be a list or a string
-        report_type :
-            Report type of expression cache (eg. Fields). It can be a list or a string (same length of expression_list) (Default value = "Fields")
-        isconvergence :
-            Boolean if expression is in convergence criteria. It can be a list or a string (same length of expression_list) (Default value = True)
-        intrinsics :
-            List of Intrinsics of expression (if any). It can be a list or a string (same length of expression_list) (Default value = '')
-        isrelativeconvergence :
-             (Default value = True)
-
+            The default is ``1``.
+                
         Returns
         -------
-        type
-            none
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         arg = ["NAME:" + self.name]
@@ -294,17 +260,17 @@ class Setup(object):
 
     @aedt_exception_handler
     def add_derivatives(self, derivative_list):
-        """Add Derivatives to setup
+        """Add derivatives to the setup.
 
         Parameters
         ----------
-        derivative_list :
-            derivative list
+        derivative_list : list
+            List of derivatives.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         arg = ["NAME:" + self.name]
@@ -316,74 +282,73 @@ class Setup(object):
 
     @aedt_exception_handler
     def enable(self, setup_name=None):
-        """Enable specific Setup
+        """Enable a setup.
 
         Parameters
         ----------
-        setup_name :
-            optional setup name (Default value = None)
+        setup_name : str, optional
+            Name of the setup. The default is ``None``.
 
         Returns
         -------
-        type
-            none
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+            
         """
         if not setup_name:
-            self.omodule.EditSetup(self.name,
-                                   [
-                                       "NAME:" + self.name,
-                                       "IsEnabled:="		, True])
-        else:
-            self.omodule.EditSetup(setup_name,
-                                   [
-                                       "NAME:" + setup_name,
-                                       "IsEnabled:="		, True])
+            setup_name = self.name
+
+        self.omodule.EditSetup(
+            setup_name,
+            [
+                "NAME:" + setup_name,
+                "IsEnabled:=", True
+            ]
+        )
         return True
 
     @aedt_exception_handler
     def disable(self, setup_name=None):
-        """Disable specific Setup
+        """Disable a setup.
 
         Parameters
         ----------
-        setup_name :
-            optional setup name (Default value = None)
+        setup_name : str, optional
+            Name of the setup. The default is ``None``.
 
         Returns
         -------
-        type
-            none
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+            
         """
         if not setup_name:
-            self.omodule.EditSetup(self.name,
-                                   [
-                                       "NAME:" + self.name,
-                                       "IsEnabled:="		, False])
+            setup_name = self.name
 
-        else:
-            self.omodule.EditSetup(setup_name,
-                                   [
-                                       "NAME:" + setup_name,
-                                       "IsEnabled:="		, False])
+        self.omodule.EditSetup(
+            setup_name,
+            [
+                "NAME:" + setup_name,
+                "IsEnabled:", False
+            ]
+        )
         return True
 
     @aedt_exception_handler
     def add_sweep(self, sweepname=None, sweeptype= "Interpolating"):
-        """Add a Sweep to the Project
+        """Add a sweep to the project.
 
         Parameters
         ----------
-        sweepname :
-            str Sweep Name (Default value = None)
-        sweeptype :
-            sweep type (Default value = "Interpolating")
+        sweepname : str, optional
+            Name of the sweep. The default is ``None``.
+        sweeptype : str, optional
+            Type of the sweep. The default is ``"Interpolating"``.
 
         Returns
         -------
         type
-            sweep object
+            Sweep object.
 
         """
         if not sweepname:
@@ -398,23 +363,29 @@ class Setup(object):
 
     @aedt_exception_handler
     def add_mesh_link(self, design_name, solution_name, parameters_dict, project_name="This Project*"):
-        """Add Mesh Link to another design. Design can be in the same project (default) or external project
+        """Add a mesh link to another design. 
 
         Parameters
         ----------
-        project_name :
-            name of project "This Project*" by default
-        design_name :
-            str name of the design
-        solution_name :
-            str, name of solution in the format "setupname : solutionname". Optionally use appname.nominal_adaptive to get nominal adaptive or appname.nominal_sweep
-        parameters_dict :
-            dictionary of parameters. Optionally use appname.available_variations.nominal_w_values_dict property to get nominal values
+        design_name : str, 
+            Name of the design.
+        solution_name : str
+            Name of the solution in the format ``"setupname : solutionname"``.
+            Optionally use :attr:`appname.nominal_adaptive` to get the
+            nominal adaptive or :attr:`appname.nominal_sweep` to get the
+            nominal sweep.
+        parameters_dict : dict
+            Dictionary of the parameters. Optionally use 
+            :attr:`appname.available_variations.nominal_w_values_dict`
+            to get the nominal values.
+        project_name : str, optional
+            Name of the project with the design. The default is ``"This Project*"``. 
+            However, you can supply the full path and name to another project.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         meshlinks = self.props["MeshLink"]
@@ -437,84 +408,80 @@ class Setup(object):
         return True
 
 class SetupCircuit(object):
-    """This Class defines the functions to initialize, create and update a Setup in Electronic Desktop
-
+    """Initializes, creates, and updates a circuit setup.
+    
     Parameters
     ----------
-    design :
-        AEDT oDesign module
-    setupmodule :
-        AEDT Module for Analysis Setup
-    setupname :
-        Setup Name
-    solutiontype :
-        Setup Type of Application.SolutionType
-    isnewsetup :
-        Boolean. True if is a new setup to be created from template. False to access existing Setup
-
-    Returns
-    -------
+    parent: str
+        Inherited parent object.
+    solutiontype: 
+        Type of the setup.
+    setupname: str, optional
+        Name of the setup. The default is ``"MySetupAuto"``.
+    isnewsetup: bool, optional
+      Whether to create the setup from a template. The default is ``True.``
+      If ``False``, access is to the existing setup.     
 
     """
     @property
     def name(self):
-        """ """
+        """Name."""
         return self._Name
 
     @name.setter
     def name(self, name):
-        """
-
-        Parameters
-        ----------
-        name :
-            
-
-        Returns
-        -------
-
-        """
         self._Name = name
         self.props["Name"] = name
 
     @property
     def parent(self):
-        """ """
+        """AEDT parent module for setting up the analysis."""
         return self._parent
 
     @parent.setter
     def parent(self, name):
-        """
-
-        Parameters
-        ----------
-        name :
-            
-
-        Returns
-        -------
-
-        """
         self._parent = name
 
     @property
     def odesign(self):
-        """ """
+        """Design."""
         return self._parent.odesign
 
     @property
     def omodule(self):
-        """ """
+        """Analysis module.
+
+        Parameters
+        ----------
+        parent: str
+            Inherited parent object.
+        solutiontype:
+            Type of the setup.
+        setupname: str, optional
+            Name of the setup. The default is ``"MySetupAuto"``.
+        isnewsetup: bool, optional
+          Whether to create the setup from a template. The default is ``True.``
+          If ``False``, access is to the existing setup.
+
+        Returns
+        -------
+        str
+            Name of the setup.
+
+        """
         return self._parent.oanalysis
 
-    def __init__(self, parent,  solutiontype, setupname="MySetupAuto", isnewsetup=True):
+    def __init__(self, parent, solutiontype, setupname="MySetupAuto", isnewsetup=True):
         self._parent = None
         self.parent = parent
-        self.setuptype = solutiontype
+        if isinstance(solutiontype, int):
+            self.setuptype = solutiontype
+        else:
+            self.setuptype = SetupKeys.defaultSetups[solutiontype]
         self._Name = "LinearFrequency"
         self.props = {}
         if isnewsetup:
-            setup_template = SetupKeys.SetupTemplates[solutiontype]
+            setup_template = SetupKeys.SetupTemplates[self.setuptype]
             for t in setup_template:
                 tuple2dict(t, self.props)
         else:
@@ -531,52 +498,14 @@ class SetupCircuit(object):
                 self.props = {}
         self.name = setupname
 
-    @aedt_exception_handler
-    def check_dict(self, listin, name, out):
-        """
-
-        Parameters
-        ----------
-        listin :
-            
-        name :
-            
-        out :
-            
-
-        Returns
-        -------
-
-        """
-        arg = ["Name:" + name.replace("__", " ")]
-        for a in listin:
-            if type(a) is tuple:
-                if type(a[1]) is list and type(a[1][0]) is tuple:
-                    arg = self.check_dict(a[1], a[0], arg)
-                else:
-                    arg.append(a[0].replace("__", " ") + ":=")
-                    arg.append(a[1])
-            else:
-                arg =name.replace("__", " ")+ ":="
-                out.append(arg)
-                arg = None
-                out.append(listin)
-                break
-        if arg:
-            out.append(arg)
-        return out
-
     @aedt_exception_handler
     def create(self):
-        """Insert a new Setup based on Class settings into the AEDT Application
+        """Add a new setup based on class settings in AEDT.
         
-        :return: the argument list
-
-        Parameters
-        ----------
-
         Returns
         -------
+        dict
+            Dictionary of the arguments.
 
         """
         soltype = SetupKeys.SetupNames[self.setuptype]
@@ -591,15 +520,18 @@ class SetupCircuit(object):
 
         Parameters
         ----------
-        soltype :
+        soltype : str
+            Type of the solution.
             
         arg :
             
-        newsetup :
-             (Default value = True)
+        newsetup : bool, optional
+            Whether this is a new setup. The default is ``True``.
 
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if newsetup:
@@ -609,6 +541,12 @@ class SetupCircuit(object):
                 self.omodule.AddDCAnalysis(arg)
             elif soltype == "NexximTransient":
                 self.omodule.AddTransient(arg)
+            elif soltype == "NexximQuickEye":
+                self.omodule.AddQuickEyeAnalysis(arg)
+            elif soltype == "NexximVerifEye":
+                self.omodule.AddVerifEyeAnalysis(arg)
+            elif soltype == "NexximAMI":
+                self.omodule.AddAMIAnalysis(arg)
             else:
                 print("Not Implemented Yet")
         else:
@@ -618,23 +556,30 @@ class SetupCircuit(object):
                 self.omodule.EditDCAnalysis(self.name, arg)
             elif soltype == "NexximTransient":
                 self.omodule.EditTransient(self.name, arg)
+            elif soltype == "NexximQuickEye":
+                self.omodule.EditQuickEyeAnalysis(self.name,arg)
+            elif soltype == "NexximVerifEye":
+                self.omodule.EditVerifEyeAnalysis(self.name,arg)
+            elif soltype == "NexximAMI":
+                self.omodule.EditAMIAnalysis(self.name,arg)
+
             else:
-                print("Not Implemented Yet")
+                raise NotImplementedError("Solution type '{}' is not implemented yet".format(soltype))
         return True
 
     @aedt_exception_handler
     def update(self, update_dictionary=None):
-        """update the setup based on the class argument or to the updated dictionary passed as arcument
+        """Update the setup based on the class arguments or a dictionary.
 
         Parameters
         ----------
-        update_dictionary :
-            optional dictionary of settings to apply (Default value = None)
+        update_dictionary : dict, optional
+            Dictionary of settings to apply. The default is ``None``.
 
         Returns
         -------
-        type
-            bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if update_dictionary:
@@ -649,26 +594,28 @@ class SetupCircuit(object):
     @aedt_exception_handler
     def _expression_cache(self, expression_list, report_type_list, intrinsics_list, isconvergence_list,
                           isrelativeconvergence, conv_criteria):
-        """
+        """Retrieve data from the expression setup cache.
 
         Parameters
         ----------
-        expression_list :
+        expressions_list : list
+            List of formulas to retrieve. 
+        report_type_list : list
+            List of report types for the expressions. 
+        intrinsics_list : list
+            List of intrinsic functions for the expressions.
+        isconvergence_list : list
+            List of Boolean values indicating whether the expressions are in 
+            the convergence criteria.
+        isrelativeconvergence : 
             
-        report_type_list :
-            
-        intrinsics_list :
-            
-        isconvergence_list :
-            
-        isrelativeconvergence :
-            
-        conv_criteria :
-            
-
+        conv_criteria:
+        
         Returns
         -------
-
+        list
+            List of the data.
+        
         """
 
         if isrelativeconvergence:
@@ -737,27 +684,31 @@ class SetupCircuit(object):
     @aedt_exception_handler
     def enable_expression_cache(self, expressions, report_type="Fields", intrinsics='', isconvergence=True,
                                 isrelativeconvergence=True, conv_criteria=1):
-        """
+        """Enable a setup expression cache.
 
         Parameters
         ----------
-        conv_criteria :
-            param isrelativeconvergence: (Default value = 1)
-        expressions :
-            Formula to be added to the expression cache. It can be a list or a string
-        report_type :
-            Report type of expression cache (eg. Fields). It can be a list or a string (same length of expression_list) (Default value = "Fields")
-        isconvergence :
-            Boolean if expression is in convergence criteria. It can be a list or a string (same length of expression_list) (Default value = True)
-        intrinsics :
-            List of Intrinsics of expression (if any). It can be a list or a string (same length of expression_list) (Default value = '')
-        isrelativeconvergence :
-             (Default value = True)
-
+        expressions : str or list
+            One or more formulas to add to the expression cache. 
+        report_type : str or list, optional
+            Type of the report for the expression. The default is ``"Fields"``. If a list of expressions
+            is supplied, a corresponding list of report types must be supplied.
+        intrinsics : str or list, optional
+            Intrinsic functions for the expressions. The default is ``""``. If a list of expressions
+            is supplied, a corresponding list of intrinsic expressesions must be supplied.
+        isconvergence : bool, str, or list, optional
+            Whether the expression is in the convergence criteria. The  default is ``True``.  
+            If a list of expressions is supplied, a corresponding list of Boolean values must be
+            supplied.
+        isrelativeconvergence : bool, optional
+            The default is ``True``.
+        conv_criteria
+            The default is ``1``.
+                
         Returns
         -------
-        type
-            none
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         arg = ["Name:SimSetup"]
@@ -770,17 +721,17 @@ class SetupCircuit(object):
 
     @aedt_exception_handler
     def add_derivatives(self, derivative_list):
-        """Add Derivatives to Setup
+        """Add derivatives to the setup.
 
         Parameters
         ----------
-        derivative_list :
-            derivative lists
+        derivative_list : list
+            List of derivatives.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         arg = ["Name:SimSetup"]
@@ -792,74 +743,80 @@ class SetupCircuit(object):
 
     @aedt_exception_handler
     def enable(self, setup_name=None):
-        """Enable specific Setup
+        """Enable a setup.
 
         Parameters
         ----------
-        setup_name :
-            optional setup name (Default value = None)
+        setup_name : str, optional
+            Name of the setup. The default is ``None``.
 
         Returns
         -------
-        type
-            none
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+            
         """
         if not setup_name:
-            self.odesign.EnableSolutionSetup(self.name, True)
-        else:
-            self.odesign.EnableSolutionSetup(setup_name, True)
+            setup_name = self.name
+        self.odesign.EnableSolutionSetup(setup_name, True)
         return True
 
     @aedt_exception_handler
     def disable(self, setup_name=None):
-        """Disable specific Setup
+        """Disable a setup.
 
         Parameters
         ----------
-        setup_name :
-            optional setup name (Default value = None)
+        setup_name : str, optional
+            Name of the setup. The default is ``None``.
 
         Returns
         -------
-        type
-            none
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+            
         """
         if not setup_name:
-            self.odesign.EnableSolutionSetup(self.name, False)
-        else:
-            self.odesign.EnableSolutionSetup(setup_name, False)
+            setup_name = self.name
+        self.odesign.EnableSolutionSetup(setup_name, False)
         return True
 
 
 class Setup3DLayout(object):
-    """This Class defines the functions to initialize, create and update a Setup in Electronic Desktop
-
+    """Initializes, creates, and updates a 3D Layout setup.
+    
     Parameters
     ----------
-    setupmodule :
-        AEDT Module for Analysis Setup
-    setupname :
-        Setup Name
-    solutiontype :
-        Setup Type of Application.SolutionType
-    isnewsetup :
-        Boolean. True if is a new setup to be created from template. False to access existing Setup
-
-    Returns
-    -------
-
+    parent: str
+        Inherited parent object.
+    solutiontype: 
+        Type of the setup.
+    setupname: str, optional
+        Name of the setup. The default is ``"MySetupAuto"``.
+    isnewsetup: bool, optional
+        Whether to create the setup from a template. The default is ``True.``
+        If ``False``, access is to the existing setup.
+    
     """
 
     @property
     def omodule(self):
-        """ """
+        """Analysis module.
+      
+        Returns
+        -------
+        type
+            Analysis module.
+
+        """
         return self.parent.oanalysis
 
     def __init__(self, parent, solutiontype, setupname="MySetupAuto", isnewsetup=True):
         self.parent = parent
-        self._solutiontype = solutiontype
+        if isinstance(solutiontype, int):
+            self._solutiontype = solutiontype
+        else:
+            self._solutiontype =SetupKeys.defaultSetups[self._solutiontype]
         self.name = setupname
         self.props = OrderedDict()
         self.sweeps = []
@@ -876,7 +833,7 @@ class Setup3DLayout(object):
                         app = setup_data["Data"]
                         for el in app:
                             if type(app[el]) is OrderedDict:
-                                self.sweeps.append(SweepHFSS(self.omodule, setupname, el, props=app[el]))
+                                self.sweeps.append(SweepHFSS3DLayout(self.omodule, setupname, el, props=app[el]))
 
                     self.props = OrderedDict(setup_data)
             except:
@@ -889,7 +846,14 @@ class Setup3DLayout(object):
 
     @property
     def setup_type(self):
-        """:return: setup type"""
+        """Setup type.
+        
+        Returns
+        -------
+        type
+            Setup type.
+        """
+        
         if 'SolveSetupType' in self.props:
             return self.props['SolveSetupType']
         else:
@@ -897,15 +861,12 @@ class Setup3DLayout(object):
 
     @aedt_exception_handler
     def create(self):
-        """Insert a new Setup based on Class settings into the AEDT Application
+        """Add a new setup based on class settings in AEDT.
         
-        :return: the argument list
-
-        Parameters
-        ----------
-
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         arg = ["NAME:" + self.name]
@@ -915,17 +876,17 @@ class Setup3DLayout(object):
 
     @aedt_exception_handler
     def update(self):
-        """update the setup based on the class argument or to the updated dictionary passed as arcument
+        """Update the setup based on the class arguments or a dictionary.
 
         Parameters
         ----------
-        update_dictionary :
-            optional dictionary of settings to apply
+        update_dictionary : dict, optional
+            Dictionary of settings to apply.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         arg = ["NAME:" + self.name]
@@ -935,17 +896,17 @@ class Setup3DLayout(object):
 
     @aedt_exception_handler
     def enable(self):
-        """Enable specific Setup
+        """Enable a setup.
 
         Parameters
         ----------
-        setup_name :
-            optional setup name
+        setup_name : str, optional
+            Name of the setup.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         self.props['Properties']['Enable'] = "true"
@@ -954,17 +915,17 @@ class Setup3DLayout(object):
 
     @aedt_exception_handler
     def disable(self):
-        """Disable specific Setup
+        """Disable a setup.
 
         Parameters
         ----------
-        setup_name :
-            optional setup name
+        setup_name : str, optional
+            Name of the setup.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         self.props['Properties']['Enable'] = "false"
@@ -973,17 +934,17 @@ class Setup3DLayout(object):
 
     @aedt_exception_handler
     def export_to_hfss(self, file_fullname):
-        """Export Project to
+        """Export the project to a file.
 
         Parameters
         ----------
-        file_fullname :
-            fullname of desgintation
+        file_fullname : str
+            Full path and file name for exporting the project.
 
         Returns
         -------
-        type
-            Bool
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
 
@@ -997,23 +958,26 @@ class Setup3DLayout(object):
 
     @aedt_exception_handler
     def add_sweep(self, sweepname=None, sweeptype="Interpolating"):
-        """Add Frequency Sweep
+        """Add a frequency sweep.
 
         Parameters
         ----------
-        sweepname :
-            str sweep name (Default value = None)
-        sweeptype :
-            str sweep type (Default value = "Interpolating")
+        sweepname : str, optional
+            Name of the sweep. The default is ``None``.
+        sweeptype : str, optional
+            Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, and 
+            ``"Discrete"``. The default is ``"Interpolating"``.
 
         Returns
         -------
-        type
-            sweep object
+        :class:`pyaedt.modules.SetupTemplates.SweepHFSS3DLayout`
+            Sweep object.
 
         """
         if not sweepname:
             sweepname = generate_unique_name("Sweep")
-        sweep_n = SweepHFSS(self.omodule, self.name, sweepname, sweeptype)
-        self.sweeps.append(sweep_n)
-        return sweep_n
\ No newline at end of file
+        sweep_n = SweepHFSS3DLayout(self.omodule, self.name, sweepname, sweeptype)
+        if sweep_n.create():
+            self.sweeps.append(sweep_n)
+            return sweep_n
+        return False
