@@ -1,13 +1,7 @@
 """
-Siwave Class
-----------------
+This module contains the `Siwave` class.  
 
-This class initializes Siwave and MessageManager and manages Siwave release and closing.
-It can be initialized as standalone before launching an app or automatically initialized by an app to the latest installed AEDT version.
-
-
-
-================
+The `Siwave` module can be initialized as standalone before launching an app or automatically initialized by an app to the latest installed AEDT version.
 
 """
 from __future__ import absolute_import
@@ -34,7 +28,7 @@ elif os.name == 'nt':
         import win32com.client
         _com = 'pywin32'
     else:
-        raise Exception("Error. No win32com.client or Pythonnet modules found. Please install them")
+        raise Exception("Error. No win32com.client or Python.NET modules found. They need to be installed.")
 
 
 # if _pythonver == 3:
@@ -44,19 +38,18 @@ elif os.name == 'nt':
 
 
 class Siwave:
-    """====================================
-    The core module that initialize Ansys Siwave based on inputs provided:
+    """Initializes SIwave based on the inputs provided and manages SIwave release and closing.
 
     Parameters
     ----------
-
-    Returns
-    -------
+    specified_version : str, optional
+        Version of AEDT to use. The default is ``None``, in which case 
+        the active setup is used or the latest installed version is used.
 
     """
     @property
     def version_keys(self):
-        """ """
+        """Version keys for AEDT."""
 
         self._version_keys = []
         self._version_ids = {}
@@ -78,7 +71,7 @@ class Siwave:
 
     @property
     def current_version(self):
-        """ """
+        """Current version of AEDT."""
         return self.version_keys[0]
 
     def __init__(self, specified_version=None):
@@ -117,7 +110,7 @@ class Siwave:
             elif _com == 'pythonnet_v3': #TODO check if possible to use pythonnet. at the moment the tool open AEDt but doesn't return the wrapper of oApp
                 print("Launching AEDT with Module win32com")
 
-                self._main.oSiwave=win32com.client.Dispatch("Siwave.Application.2020.2")
+                self._main.oSiwave=win32com.client.Dispatch("Siwave.Application.2021.1")
 
             self._main.AEDTVersion = version_key
             self.oSiwave = self._main.oSiwave
@@ -147,55 +140,101 @@ class Siwave:
 
     @property
     def project_name(self):
-        """ """
+        """Project name.
+        
+        Returns
+        -------
+        str
+            Name of the project.
+        
+        """
         return self._oproject.GetName()
 
 
     @property
     def project_path(self):
-        """ """
+        """Project path.
+        
+        Returns
+        -------
+        str
+            Full absolute path for the project.
+        
+        """
         return os.path.normpath(self.oSiwave.GetProjectDirectory())
 
     @property
     def project_file(self):
-        """ """
+        """Project file.
+        
+        Returns
+        -------
+        str
+            Full absolute path and name for the project file.
+        
+        """
         return os.path.join(self.project_path, self.project_name + '.siw')
 
     @property
     def lock_file(self):
-        """ """
+        """Lock file.
+        
+        Returns
+        -------
+        str
+            Full absolute path and name for the project lock file.
+            
+        """
         return os.path.join(self.project_path, self.project_name + '.siw.lock')
 
     @property
     def results_directory(self):
-        """ """
+        """Results directory.
+        
+        Returns
+        -------
+        str
+            Full absolute path to the ``aedtresults`` directory.
+        """
         return os.path.join(self.project_path, self.project_name + '.siwresults')
 
 
     @property
     def src_dir(self):
-        """ """
+        """Source directory.
+        
+        Returns
+        -------
+        str
+            Full absolute path to the ``python`` directory.
+        """
         return os.path.dirname(os.path.realpath(__file__))
 
     @property
     def pyaedt_dir(self):
-        """ """
+        """PyAEDT directory.
+        
+        Returns
+        -------
+        str
+            Full absolute path to the ``pyaedt`` directory.
+        """
         return os.path.realpath(os.path.join(self.src_dir, '..'))
 
 
     @property
     def oproject(self):
-        """ """
+        """Project."""
         return self._oproject
 
     @aedt_exception_handler
     def open_project(self, proj_path=None):
-        """
+        """Open a project.
 
         Parameters
         ----------
-        proj_path :
-             (Default value = None)
+        proj_path : str, optional
+            Full path to the project. The default is ``None``.
 
         Returns
         -------
@@ -209,17 +248,19 @@ class Siwave:
 
     @aedt_exception_handler
     def save_project(self, projectpath=None, projectName=None):
-        """
+        """Save the project.
 
         Parameters
         ----------
-        projectpath :
-             (Default value = None)
-        projectName :
-             (Default value = None)
+        proj_path : str, optional
+            Full path to the project. The default is ``None``.
+        projectName : str, optional
+             Name of the project. The default is ``None``.
 
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if projectName and projectpath:
@@ -231,8 +272,13 @@ class Siwave:
 
     @aedt_exception_handler
     def quit_application(self):
-        """ """
-
+        """Quit the application.
+        
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
+        """
         self._main.oSiwave.Quit()
         return True
-
